==> integration-tests-jobs-service-springboot-1.7.0.Final-sources.jar: org/acme/travels/TimersOnTaskModelOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "timersOnTask", name = "TimersOnTask", hidden = true)
public class TimersOnTaskModelOutput implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("delay", this.delay);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(getId(), params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.delay = (java.lang.String) params.get("delay");
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "delay")
    private java.lang.String delay;

    public java.lang.String getDelay() {
        return delay;
    }

    public void setDelay(java.lang.String delay) {
        this.delay = delay;
    }
}

==> integration-tests-jobs-service-springboot-1.8.0.Final-sources.jar: org/acme/travels/TimersOnTaskModelOutput.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.MappableToModel;
import org.kie.kogito.Model;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "timersOnTask", name = "TimersOnTask", hidden = true)
public class TimersOnTaskModelOutput implements Model, MappableToModel<TimersOnTaskModel> {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap<>();
        params.put("delay", this.delay);
        return params;
    }

    @Override
    public TimersOnTaskModelOutput fromMap(Map<String, Object> params) {
        return fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(getId(), params);
    }

    public TimersOnTaskModelOutput fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.delay = (java.lang.String) params.get("delay");
        return this;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "delay")
    @javax.validation.Valid()
    private java.lang.String delay;

    public java.lang.String getDelay() {
        return delay;
    }

    public void setDelay(java.lang.String delay) {
        this.delay = delay;
    }

    @Override()
    public TimersOnTaskModel toModel() {
        TimersOnTaskModel result = new TimersOnTaskModel();
        result.setId(getId());
        result.setDelay(getDelay());
        return result;
    }
}
